==> telectron-1.2.23-py3-none-any.whl: telectron/raw/types/stats/broadcast_stats.py <==
#  telectron - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of telectron.
#
#  telectron is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  telectron is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with telectron.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from telectron.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from telectron.raw.core import TLObject
from telectron import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class BroadcastStats(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~telectron.raw.base.stats.BroadcastStats`.

    Details:
        - Layer: ``129``
        - ID: ``0xbdf78394``

    Parameters:
        period: :obj:`StatsDateRangeDays <telectron.raw.base.StatsDateRangeDays>`
        followers: :obj:`StatsAbsValueAndPrev <telectron.raw.base.StatsAbsValueAndPrev>`
        views_per_post: :obj:`StatsAbsValueAndPrev <telectron.raw.base.StatsAbsValueAndPrev>`
        shares_per_post: :obj:`StatsAbsValueAndPrev <telectron.raw.base.StatsAbsValueAndPrev>`
        enabled_notifications: :obj:`StatsPercentValue <telectron.raw.base.StatsPercentValue>`
        growth_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        followers_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        mute_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        top_hours_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        interactions_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        iv_interactions_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        views_by_source_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        new_followers_by_source_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        languages_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        recent_message_interactions: List of :obj:`MessageInteractionCounters <telectron.raw.base.MessageInteractionCounters>`

    See Also:
        This object can be returned by 1 method:

        .. hlist::
            :columns: 2

            - :obj:`stats.GetBroadcastStats <telectron.raw.functions.stats.GetBroadcastStats>`
    """

    __slots__: List[str] = ["period", "followers", "views_per_post", "shares_per_post", "enabled_notifications", "growth_graph", "followers_graph", "mute_graph", "top_hours_graph", "interactions_graph", "iv_interactions_graph", "views_by_source_graph", "new_followers_by_source_graph", "languages_graph", "recent_message_interactions"]

    ID = 0xbdf78394
    QUALNAME = "types.stats.BroadcastStats"

    def __init__(self, *, period: "raw.base.StatsDateRangeDays", followers: "raw.base.StatsAbsValueAndPrev", views_per_post: "raw.base.StatsAbsValueAndPrev", shares_per_post: "raw.base.StatsAbsValueAndPrev", enabled_notifications: "raw.base.StatsPercentValue", growth_graph: "raw.base.StatsGraph", followers_graph: "raw.base.StatsGraph", mute_graph: "raw.base.StatsGraph", top_hours_graph: "raw.base.StatsGraph", interactions_graph: "raw.base.StatsGraph", iv_interactions_graph: "raw.base.StatsGraph", views_by_source_graph: "raw.base.StatsGraph", new_followers_by_source_graph: "raw.base.StatsGraph", languages_graph: "raw.base.StatsGraph", recent_message_interactions: List["raw.base.MessageInteractionCounters"]) -> None:
        self.period = period  # StatsDateRangeDays
        self.followers = followers  # StatsAbsValueAndPrev
        self.views_per_post = views_per_post  # StatsAbsValueAndPrev
        self.shares_per_post = shares_per_post  # StatsAbsValueAndPrev
        self.enabled_notifications = enabled_notifications  # StatsPercentValue
        self.growth_graph = growth_graph  # StatsGraph
        self.followers_graph = followers_graph  # StatsGraph
        self.mute_graph = mute_graph  # StatsGraph
        self.top_hours_graph = top_hours_graph  # StatsGraph
        self.interactions_graph = interactions_graph  # StatsGraph
        self.iv_interactions_graph = iv_interactions_graph  # StatsGraph
        self.views_by_source_graph = views_by_source_graph  # StatsGraph
        self.new_followers_by_source_graph = new_followers_by_source_graph  # StatsGraph
        self.languages_graph = languages_graph  # StatsGraph
        self.recent_message_interactions = recent_message_interactions  # Vector<MessageInteractionCounters>

    @staticmethod
    def read(data: BytesIO, *args: Any) -> "BroadcastStats":
        # No flags
        
        period = TLObject.read(data)
        
        followers = TLObject.read(data)
        
        views_per_post = TLObject.read(data)
        
        shares_per_post = TLObject.read(data)
        
        enabled_notifications = TLObject.read(data)
        
        growth_graph = TLObject.read(data)
        
        followers_graph = TLObject.read(data)
        
        mute_graph = TLObject.read(data)
        
        top_hours_graph = TLObject.read(data)
        
        interactions_graph = TLObject.read(data)
        
        iv_interactions_graph = TLObject.read(data)
        
        views_by_source_graph = TLObject.read(data)
        
        new_followers_by_source_graph = TLObject.read(data)
        
        languages_graph = TLObject.read(data)
        
        recent_message_interactions = TLObject.read(data)
        
        return BroadcastStats(period=period, followers=followers, views_per_post=views_per_post, shares_per_post=shares_per_post, enabled_notifications=enabled_notifications, growth_graph=growth_graph, followers_graph=followers_graph, mute_graph=mute_graph, top_hours_graph=top_hours_graph, interactions_graph=interactions_graph, iv_interactions_graph=iv_interactions_graph, views_by_source_graph=views_by_source_graph, new_followers_by_source_graph=new_followers_by_source_graph, languages_graph=languages_graph, recent_message_interactions=recent_message_interactions)

    def write(self) -> bytes:
        data = BytesIO()
        data.write(Int(self.ID, False))

        # No flags
        
        data.write(self.period.write())
        
        data.write(self.followers.write())
        
        data.write(self.views_per_post.write())
        
        data.write(self.shares_per_post.write())
        
        data.write(self.enabled_notifications.write())
        
        data.write(self.growth_graph.write())
        
        data.write(self.followers_graph.write())
        
        data.write(self.mute_graph.write())
        
        data.write(self.top_hours_graph.write())
        
        data.write(self.interactions_graph.write())
        
        data.write(self.iv_interactions_graph.write())
        
        data.write(self.views_by_source_graph.write())
        
        data.write(self.new_followers_by_source_graph.write())
        
        data.write(self.languages_graph.write())
        
        data.write(Vector(self.recent_message_interactions))
        
        return data.getvalue()

==> telectron-1.2.42-py3-none-any.whl: telectron/raw/types/stats/broadcast_stats.py <==
#  telectron - Telegram MTProto API Client Library for Python
#  Copyright (C) 2017-2021 Dan <https://github.com/delivrance>
#
#  This file is part of telectron.
#
#  telectron is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  telectron is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License
#  along with telectron.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from telectron.raw.core.primitives import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector
from telectron.raw.core import TLObject
from telectron import raw
from typing import List, Union, Any

# # # # # # # # # # # # # # # # # # # # # # # #
#               !!! WARNING !!!               #
#          This is a generated file!          #
# All changes made in this file will be lost! #
# # # # # # # # # # # # # # # # # # # # # # # #


class BroadcastStats(TLObject):  # type: ignore
    """This object is a constructor of the base type :obj:`~telectron.raw.base.stats.BroadcastStats`.

    Details:
        - Layer: ``134``
        - ID: ``0xbdf78394``

    Parameters:
        period: :obj:`StatsDateRangeDays <telectron.raw.base.StatsDateRangeDays>`
        followers: :obj:`StatsAbsValueAndPrev <telectron.raw.base.StatsAbsValueAndPrev>`
        views_per_post: :obj:`StatsAbsValueAndPrev <telectron.raw.base.StatsAbsValueAndPrev>`
        shares_per_post: :obj:`StatsAbsValueAndPrev <telectron.raw.base.StatsAbsValueAndPrev>`
        enabled_notifications: :obj:`StatsPercentValue <telectron.raw.base.StatsPercentValue>`
        growth_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        followers_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        mute_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        top_hours_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        interactions_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        iv_interactions_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        views_by_source_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        new_followers_by_source_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        languages_graph: :obj:`StatsGraph <telectron.raw.base.StatsGraph>`
        recent_message_interactions: List of :obj:`MessageInteractionCounters <telectron.raw.base.MessageInteractionCounters>`

    See Also:
        This object can be returned by 1 method:

        .. hlist::
            :columns: 2

            - :obj:`stats.GetBroadcastStats <telectron.raw.functions.stats.GetBroadcastStats>`
    """

    __slots__: List[str] = ["period", "followers", "views_per_post", "shares_per_post", "enabled_notifications", "growth_graph", "followers_graph", "mute_graph", "top_hours_graph", "interactions_graph", "iv_interactions_graph", "views_by_source_graph", "new_followers_by_source_graph", "languages_graph", "recent_message_interactions"]

    ID = 0xbdf78394
    QUALNAME = "types.stats.BroadcastStats"

    def __init__(self, *, period: "raw.base.StatsDateRangeDays", followers: "raw.base.StatsAbsValueAndPrev", views_per_post: "raw.base.StatsAbsValueAndPrev", shares_per_post: "raw.base.StatsAbsValueAndPrev", enabled_notifications: "raw.base.StatsPercentValue", growth_graph: "raw.base.StatsGraph", followers_graph: "raw.base.StatsGraph", mute_graph: "raw.base.StatsGraph", top_hours_graph: "raw.base.StatsGraph", interactions_graph: "raw.base.StatsGraph", iv_interactions_graph: "raw.base.StatsGraph", views_by_source_graph: "raw.base.StatsGraph", new_followers_by_source_graph: "raw.base.StatsGraph", languages_graph: "raw.base.StatsGraph", recent_message_interactions: List["raw.base.MessageInteractionCounters"]) -> None:
        self.period = period  # StatsDateRangeDays
        self.followers = followers  # StatsAbsValueAndPrev
        self.views_per_post = views_per_post  # StatsAbsValueAndPrev
        self.shares_per_post = shares_per_post  # StatsAbsValueAndPrev
        self.enabled_notifications = enabled_notifications  # StatsPercentValue
        self.growth_graph = growth_graph  # StatsGraph
        self.followers_graph = followers_graph  # StatsGraph
        self.mute_graph = mute_graph  # StatsGraph
        self.top_hours_graph = top_hours_graph  # StatsGraph
        self.interactions_graph = interactions_graph  # StatsGraph
        self.iv_interactions_graph = iv_interactions_graph  # StatsGraph
        self.views_by_source_graph = views_by_source_graph  # StatsGraph
        self.new_followers_by_source_graph = new_followers_by_source_graph  # StatsGraph
        self.languages_graph = languages_graph  # StatsGraph
        self.recent_message_interactions = recent_message_interactions  # Vector<MessageInteractionCounters>

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "BroadcastStats":
        # No flags
        
        period = TLObject.read(b)
        
        followers = TLObject.read(b)
        
        views_per_post = TLObject.read(b)
        
        shares_per_post = TLObject.read(b)
        
        enabled_notifications = TLObject.read(b)
        
        growth_graph = TLObject.read(b)
        
        followers_graph = TLObject.read(b)
        
        mute_graph = TLObject.read(b)
        
        top_hours_graph = TLObject.read(b)
        
        interactions_graph = TLObject.read(b)
        
        iv_interactions_graph = TLObject.read(b)
        
        views_by_source_graph = TLObject.read(b)
        
        new_followers_by_source_graph = TLObject.read(b)
        
        languages_graph = TLObject.read(b)
        
        recent_message_interactions = TLObject.read(b)
        
        return BroadcastStats(period=period, followers=followers, views_per_post=views_per_post, shares_per_post=shares_per_post, enabled_notifications=enabled_notifications, growth_graph=growth_graph, followers_graph=followers_graph, mute_graph=mute_graph, top_hours_graph=top_hours_graph, interactions_graph=interactions_graph, iv_interactions_graph=iv_interactions_graph, views_by_source_graph=views_by_source_graph, new_followers_by_source_graph=new_followers_by_source_graph, languages_graph=languages_graph, recent_message_interactions=recent_message_interactions)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(self.period.write())
        
        b.write(self.followers.write())
        
        b.write(self.views_per_post.write())
        
        b.write(self.shares_per_post.write())
        
        b.write(self.enabled_notifications.write())
        
        b.write(self.growth_graph.write())
        
        b.write(self.followers_graph.write())
        
        b.write(self.mute_graph.write())
        
        b.write(self.top_hours_graph.write())
        
        b.write(self.interactions_graph.write())
        
        b.write(self.iv_interactions_graph.write())
        
        b.write(self.views_by_source_graph.write())
        
        b.write(self.new_followers_by_source_graph.write())
        
        b.write(self.languages_graph.write())
        
        b.write(Vector(self.recent_message_interactions))
        
        return b.getvalue()
